@@ -25,56 +25,61 @@ iris_data = iris_data.loc[:, ["class", "sepal_length", "sepal_width"]]
 
 iris_summary = iris_data.groupby("class").agg(np.mean)
 iris_summary.index = [_[5:].capitalize() for _ in iris_summary.index]
+iris_summary.reset_index(inplace=True)
 iris_summary.rename(
     columns={
-        "class": "class",
+        "index": "Class",
         "sepal_length": "Mean Sepal Length",
         "sepal_width": "Mean Sepal Width",
     },
     inplace=True,
     )
 
-# Drop index into table
-iris_summary.reset_index(inplace=True)
-
-# Insert NA to demonstrate missing value representation
-iris_summary.iloc[1, 1] = np.nan
-
 ## Define table elements
-title = ["Mean", {"italic": True}, " Iris", "$$note2$$ sepal dimensions"]
+table_name = "iris_statistics"
+title = "Mean Iris$$note2$$ sepal dimensions"
 subtitles = [
     "1936 Fisher, R.A; The use of multiple measurements in taxonomic problems$$note1$$",
-    "Just another subtitile",
+    "Just another subtitle"
     ]
-units = "cm"
+units = {1:"cm", 2:"cm"}
+table_notes = {0: "$$note1$$", 2: "$$note3$$"}
 scope = "Iris"
 source = "Source: Office for Iris Statistics"
 index = {2: 0}  # Column 0 is a level 2 index
-annotations = {
-    "note1": "I've got 99 problems and taxonomy is one.",
-    "note2": "Goo Goo Dolls, 1998.",
-    }
-notes = ["This note hath no reference."]
 
 # or use kwargs to pass these to the appropriate parameters
 kwargs = {
+    "table_name": table_name,
     "title": title,
     "subtitles": subtitles,
     "units": units,
+    "table_notes": table_notes,
     "scope": scope,
     "source": source,
     "index_columns": index,
-    "annotations": annotations,
-    "notes": notes,
     }
 
 ## Define our GPTable
 iris_table = gpt.GPTable(table=iris_summary, **kwargs)
 
+sheets = {"Iris Flower Dimensions": iris_table}
+
+## Notesheet
+notes = {
+    "Note reference": ["note1", "note2", "note3"],
+    "Note text": ["I've got 99 problems and taxonomy is one.", "Goo Goo Dolls, 1998.", "Just another note"],
+    "Useful link": ["[google](https://www.google.com)", "[duckduckgo](https://duckduckgo.com/)", "[ONS](https://www.ons.gov.uk)"],
+    }
+notes_table = pd.DataFrame.from_dict(notes)
+
 ## Use write_workbook to win!
 if __name__ == "__main__":
     output_path = parent_dir / "python_iris_gptable.xlsx"
     gpt.write_workbook(
-        filename=output_path, sheets={"Iris Flower Dimensions": iris_table}
+        filename=output_path, 
+        sheets=sheets,
+        notes_table=notes_table,
+        contentsheet_options={"additional_elements": ["subtitles", "scope"]}
         )
     print("Output written at: ", output_path)
